import java.awt.*;
import java.awt.geom.*;

class HexGridSpinner
{
  private NeighborGrid neighborGrid;
  private int x;
  private int y;
  private int spinnerWidth;
  private int spinnerHeight;
  private Polygon polygon;
  private int weight;

  public HexGridSpinner(int x, int y, int width, int height, int weight)
  {
    this.neighborGrid = neighborGrid;
    this.x = x;
    this.y = y;
    spinnerWidth = width;
    spinnerHeight = height;
    this.weight = weight;
  }

  private Polygon getPolygon(int x, int y)
  {
    int x1 = x + spinnerWidth / 2;
    int x2 = x + spinnerWidth;
    int y1 = y + spinnerHeight / 3;
    int y2 = y + 2 * spinnerHeight /3;
    int y3 = y + spinnerHeight;
    Polygon polygon = new Polygon();
    polygon.addPoint(x, y1);
    polygon.addPoint(x1, y);
    polygon.addPoint(x2, y1);
    polygon.addPoint(x2, y2);
    polygon.addPoint(x1, y3);
    polygon.addPoint(x, y2);
    return polygon;
  }

  private void drawWeight(Graphics g)
  {
    FontMetrics fm = g.getFontMetrics();
    String s = "" + weight;
    Rectangle2D bounds = fm.getStringBounds(s, g);
    int xOffset = x + (spinnerWidth - (int)bounds.getWidth()) / 2;
    int yOffset = y + (spinnerHeight + (int)bounds.getHeight()) / 2;
    g.drawString(s, xOffset, yOffset);
  }

  public void draw(Graphics g) 
  {
    if (polygon == null)
      polygon = getPolygon(x, y);
    g.setColor(Color.black);
    g.drawPolygon(polygon);
    drawWeight(g);
  }

  public boolean contains(int x, int y)
  {
    return polygon.contains(x, y);
  }

  public int getWeight()
  {
    return weight;
  }

  public void setWeight(int weight)
  {
    this.weight = weight;
  }
}