import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

public class NewWorld extends JDialog implements ActionListener, DocumentListener
{
  private int columns;
  private int rows;
  private String selectedRule;

  private boolean changed;

  private JLabel columnsLabel;
  private JTextField columnsInput;
  private JLabel rowsLabel;
  private JTextField rowsInput;
  private ButtonGroup ruleSelector;
  private JRadioButton FrankBussButton;
  private JRadioButton PaulCallahanButton;
  private JRadioButton ruleTableButton;
  private JButton okButton;
  private JButton cancelButton;

  public NewWorld(JFrame owner, int columns, int rows, String selectedRule)
  {
    super(owner, "New World", true);
    this.columns = columns;
    this.rows = rows;
    this.selectedRule = selectedRule;
    columnsLabel = new JLabel("Columns");
    columnsInput = new JTextField("" + columns, 4);
    columnsInput.getDocument().addDocumentListener(this);
    rowsLabel = new JLabel("Rows");
    rowsInput = new JTextField("" + rows, 4);
    rowsInput.getDocument().addDocumentListener(this);
    ruleSelector = new ButtonGroup();
    FrankBussButton = new JRadioButton("Frank Buss");
    FrankBussButton.addActionListener(this);
    ruleSelector.add(FrankBussButton);
    PaulCallahanButton = new JRadioButton("Paul Callahan");
    PaulCallahanButton.addActionListener(this);
    ruleSelector.add(PaulCallahanButton);
    ruleTableButton = new JRadioButton("Rule Table");
    ruleTableButton.addActionListener(this);
    ruleSelector.add(ruleTableButton);
    if (selectedRule.equals("Frank Buss Rule"))
      FrankBussButton.setSelected(true);
    else if (selectedRule.equals("Paul Callahan Rule"))
      PaulCallahanButton.setSelected(true);
    else if (selectedRule.equals("Rule Table"))
      ruleTableButton.setSelected(true);
    okButton = new JButton("Ok");
    okButton.addActionListener(this);
    cancelButton = new JButton("Cancel");
    cancelButton.addActionListener(this);
    JPanel basePanel = new JPanel();
    basePanel.setBorder(BorderFactory.createLineBorder(basePanel.getBackground(), 15));
    JPanel worldSizePanel = new JPanel();
    worldSizePanel.setLayout(new GridLayout(2, 2, 5, 5));
    JPanel columnsInputPanel = new JPanel();
    columnsInputPanel.add(columnsInput);
    JPanel rowsInputPanel = new JPanel();
    rowsInputPanel.add(rowsInput);
    worldSizePanel.add(columnsLabel);
    worldSizePanel.add(columnsInputPanel);
    worldSizePanel.add(rowsLabel);
    worldSizePanel.add(rowsInputPanel);
    worldSizePanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "World Size"));
    JPanel ruleSelectorPanel = new JPanel();
    ruleSelectorPanel.setLayout(new GridLayout(3, 1, 5, 5));
    ruleSelectorPanel.add(FrankBussButton);
    ruleSelectorPanel.add(PaulCallahanButton);
    ruleSelectorPanel.add(ruleTableButton);
    ruleSelectorPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "Rule Selector"));
    JPanel optionsPanel = new JPanel();
    optionsPanel.setLayout(new FlowLayout(FlowLayout.LEFT, 10, 5));
    optionsPanel.add(worldSizePanel);
    optionsPanel.add(ruleSelectorPanel);
    JPanel buttonPanel = new JPanel();
    buttonPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
    buttonPanel.add(okButton);
    buttonPanel.add(cancelButton);
    basePanel.setLayout(new BorderLayout(0, 5));
    basePanel.add(optionsPanel, BorderLayout.NORTH);
    basePanel.add(buttonPanel, BorderLayout.SOUTH);
    add(basePanel);
    pack();
    setResizable(false);
    basePanel.requestFocus();
    changed = false;
    setValues();
  }

  private void setValues()
  {
    try
    {
      int c = new Integer(columnsInput.getText().trim());
      int r = new Integer(rowsInput.getText().trim());
      if (c % 2 != 0)
        c++;
      if (r % 2 != 0)
        r++;
      columns = c;
      if (columns < 10)
        columns = 10;
      rows = r;
      if (rows < 10)
        rows = 10;
    }
    catch (Exception e)
    {
    }
  }

  public int getColumns()
  {
    return columns;
  }

  public int getRows()
  {
    return rows;
  }

  public String getSelectedRule()
  {
    return selectedRule;
  }

  public boolean hasChanged()
  {
    return changed;
  }

  public void actionPerformed(ActionEvent e)
  {
    Object source = e.getSource();
    if (source == FrankBussButton)
      selectedRule = "Frank Buss";
    else if (source == PaulCallahanButton)
      selectedRule = "Paul Callahan";
    else if (source ==  ruleTableButton)
      selectedRule = "Rule Table";
    else if (source == okButton)
    {
      setVisible(false);
      changed = true;
    }
    else if (source == cancelButton)
    {
      setVisible(false);
      changed = false;
    }
  }

  public void insertUpdate(DocumentEvent event)
  {
    setValues();
  }
  
  public void removeUpdate(DocumentEvent event)
  {
    setValues();
  }
  
  public void changedUpdate(DocumentEvent event) {}
}
