import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

public class RandomOptionsDialog extends JDialog implements ActionListener, DocumentListener
{

  private boolean clear;
  private boolean allStates;
  private int singleState;
  private int density;
  private boolean changed;

  private JLabel densityLabel;
  private JTextField densityInput;
  private ButtonGroup initOptionSelector;
  private JRadioButton clearButton;
  private JRadioButton overlayButton;
  private ButtonGroup noStatesSelector;
  private JRadioButton allStatesButton;
  private JRadioButton singleStateButton;
  private JButton okButton;
  private JButton cancelButton;

  public RandomOptionsDialog(JFrame owner)
  {
    super(owner, "Random", true);
    densityLabel = new JLabel("% Density");
    densityInput = new JTextField("" + density, 3);

    densityInput.getDocument().addDocumentListener(this);
    initOptionSelector = new ButtonGroup();
    clearButton = new JRadioButton("Clear");
    clearButton.addActionListener(this);
    initOptionSelector.add(clearButton);
    overlayButton = new JRadioButton("Overlay");
    overlayButton.addActionListener(this);
    initOptionSelector.add(overlayButton);
    clearButton.setSelected(true);

    noStatesSelector = new ButtonGroup();
    allStatesButton = new JRadioButton("All States");
    allStatesButton.addActionListener(this);
    noStatesSelector.add(allStatesButton);
    singleStateButton = new JRadioButton("Single State");
    singleStateButton.addActionListener(this);
    noStatesSelector.add(singleStateButton);
    allStatesButton.setSelected(true);

    okButton = new JButton("Ok");
    okButton.addActionListener(this);
    cancelButton = new JButton("Cancel");
    cancelButton.addActionListener(this);
    JPanel basePanel = new JPanel();

    basePanel.setBorder(BorderFactory.createLineBorder(basePanel.getBackground(), 15));
    JPanel densityPanel = new JPanel();
    densityPanel.setLayout(new GridLayout(1, 2, 5, 5));
    JPanel densityInputPanel = new JPanel();
    densityInputPanel.add(densityInput);
    densityPanel.add(densityLabel);
    densityPanel.add(densityInputPanel);
    densityPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), ""));

    JPanel initOptionPanel = new JPanel();
    initOptionPanel.setLayout(new GridLayout(2, 1, 5, 5));
    initOptionPanel.add(clearButton);
    initOptionPanel.add(overlayButton);
    initOptionPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "Initialization Option"));

    JPanel noStatesPanel = new JPanel();
    noStatesPanel.setLayout(new GridLayout(2, 1, 5, 5));
    noStatesPanel.add(allStatesButton);
    noStatesPanel.add(singleStateButton);
    noStatesPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "No States"));

    JPanel optionsPanel = new JPanel();
    optionsPanel.setLayout(new GridLayout(2, 1, 5, 5));
    optionsPanel.add(initOptionPanel);
    optionsPanel.add(noStatesPanel);

    JPanel buttonPanel = new JPanel();
    buttonPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
    buttonPanel.add(okButton);
    buttonPanel.add(cancelButton);

    basePanel.setLayout(new BorderLayout(0, 5));
    basePanel.add(densityPanel, BorderLayout.NORTH);
    basePanel.add(optionsPanel, BorderLayout.CENTER);
    basePanel.add(buttonPanel, BorderLayout.SOUTH);
    add(basePanel);
    pack();
    setResizable(false);
    basePanel.requestFocus();
    changed = false;
  }

  private void setValues()
  {
    try
    {
      int s = new Integer(densityInput.getText().trim());
      density = s;
      if (density < 1)
        density = 1;
      if (density > 100)
        density = 100;
    }
    catch (Exception e)
    {
    }
  }

  public void setData(HexagonalCell hexagonalCell)
  {
    density = hexagonalCell.getRandomDensity();
    densityInput.setText("" + density);
    if (hexagonalCell.getRandomClear())
      clearButton.setSelected(true);
    else
      overlayButton.setSelected(true);
    if (hexagonalCell.getRandomAllStates())
      allStatesButton.setSelected(true);
    else
      singleStateButton.setSelected(true);
  }

  public void getData(HexagonalCell hexagonalCell)
  {
    hexagonalCell.setRandomDensity(density);
    if (clearButton.isSelected())
      hexagonalCell.setRandomClear(true);
    else
      hexagonalCell.setRandomClear(false);
    if (allStatesButton.isSelected())
      hexagonalCell.setRandomAllStates(true);
    else
      hexagonalCell.setRandomAllStates(false);
  }

  public boolean hasChanged()
  {
    return changed;
  }

  public void actionPerformed(ActionEvent e)
  {
    Object source = e.getSource();
    if (source == clearButton)
      clear = true;
    else if (source == overlayButton)
      clear = false;
    else if (source == allStatesButton)
      allStates = true;
    else if (source == singleStateButton)
      allStates = false;
    else if (source == okButton)
    {
      setVisible(false);
      changed = true;
    }
    else if (source == cancelButton)
    {
      setVisible(false);
      changed = false;
    }
  }

  public void insertUpdate(DocumentEvent event)
  {
    setValues();
  }
  
  public void removeUpdate(DocumentEvent event)
  {
    setValues();
  }
  
  public void changedUpdate(DocumentEvent event) {}
}
